Crate ssb_handshake

Based on Duncan’s fantastic Scuttlebutt Protocol Guide (repo), which he graciously released into the public domain.

Modules

  • Experimental synchronous implementation, using genio Read/Write traits, mostly for no_std environments.

Enums

Functions

  • Perform the client side of the handshake over an AsyncRead + AsyncWrite stream. Closes the stream on handshake failure.
  • Perform the server side of the handshake using the given AsyncRead + AsyncWrite stream. Closes the stream on handshake failure.